/* 
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* $Id: XMLizable.java 627367 2008-02-13 12:03:30Z maxberger $ */

package org.apache.fop.util;

/* 
 * Copied from Apache Excalibur:
 * https://svn.apache.org/repos/asf/excalibur/trunk/components/xmlutil/
 *                                           src/java/org/apache/excalibur/xml/sax/XMLizable.java
 */

/**
 * This interface can be implemented by classes willing to provide an XML representation
 * of their current state as SAX events.
 * @deprecated Use the interface in Apache XML Graphics Commons instead.
 */
public interface XMLizable extends org.apache.xmlgraphics.util.XMLizable {
    
}
